@@ -23,7 +23,6 @@ from .async_result import AsyncResult
 from .client_builder import (
     create_client_auth,
     create_gql_client,
-    get_jwt_token,
 )
 from .custom_environment import create_environment
 from .doc import (
@@ -37,7 +36,6 @@ from .functions import (
 from .namespaces import (
     BaseNamespace,
     create_function_namespace,
-    create_operation_namespace,
     create_type_namespace,
 )
 from .result_mixin import ResultMixin
@@ -64,47 +62,30 @@ def _is_valid_function_mutation(name: str) -> bool:
     return name.startswith("core__")
 
 
-def build_namespaces(qc: "Qctrl"):  # pylint:disable=invalid-name
-    """Builds features and organizes them into namespaces.
+def build_and_bind_namespaces(qctrl: "Qctrl") -> None:
+    """Builds features, organizes them into namespaces and binds the namespace to the
+    qctrl object.
 
     Parameters
     ----------
-    qc : Qctrl
+    qctrl : Qctrl
         The Qctrl object.
-
-
-    Returns
-    -------
-    tuple
-        The BaseNamespace objects in the following
-        order - function, operation, type.
     """
     function_namespace = create_function_namespace()
-    operation_namespace = create_operation_namespace()
     type_namespace = create_type_namespace()
 
-    # operations
-    for node_cls in NODE_REGISTRY.as_list():
-        func = node_cls.create_pf()
-        operation_namespace.extend_functions(func)
-    for type_cls in TYPE_REGISTRY:
-        operation_namespace.extend({type_cls.__name__: type_cls})
-
-    # functions and types
-    mutation_type = qc.gql_api.schema.mutation_type
+    # build namespace for functions and types for GQL
+    mutation_type = qctrl.gql_api.schema.mutation_type
 
     for name, field in mutation_type.fields.items():
         if _is_valid_function_mutation(name):
-            func = build_function(qc, name, field)
+            func = build_function(qctrl, name, field)
             function_namespace.extend_functions(func)
 
-    type_namespace.add_registry(qc.gql_env.type_registry)
+    type_namespace.add_registry(qctrl.gql_env.type_registry)
 
-    return (
-        function_namespace,
-        operation_namespace,
-        type_namespace,
-    )
+    setattr(qctrl, "functions", function_namespace)
+    setattr(qctrl, "types", type_namespace)
 
 
-__all__ = ["build_namespaces"]
+__all__ = ["build_and_bind_namespaces"]
