@@ -532,13 +532,10 @@ def add_deprecation_warning(object_name: str) -> str:
     str
         formatted warning docstring.
     """
-    deprecation_warning = (
-        """
+    deprecation_warning = f"""
 Warning
 -------
-`%s` will be deprecated soon. Please use
+`{object_name}` will be deprecated soon. Please use
 :class:`qctrl.dynamic.namespaces.TypeNamespace` instead.
 """
-        % object_name
-    )
     return deprecation_warning
