@@ -109,11 +109,10 @@ class ObjectHandler(BaseHandler, SelectionMixin, DataMixin):
 
             attr = self._env.field_to_attr(field_name)
 
-            if hasattr(obj, attr):
-                # if the target `getattr(obj, attr)` is None
-                # use obj itself instead to update data
+            current_attr_value = getattr(obj, attr, None)
+            if current_attr_value:
                 nested_value = self._env.update_data(
-                    field.type, getattr(obj, attr) or obj, nested_data
+                    field.type, current_attr_value, nested_data
                 )
             else:
                 nested_value = self._env.load_data(field.type, nested_data)
