@@ -18,11 +18,15 @@ from typing import (
     Callable,
     Dict,
     List,
+    Optional,
 )
 
 import inflection
 
-from qctrl.dynamic import dynamic_class
+from qctrl.dynamic import (
+    BoulderModule,
+    dynamic_class,
+)
 
 LOGGER = logging.getLogger(__name__)
 
@@ -48,14 +52,13 @@ class BaseNamespace(SimpleNamespace):
 
         Parameters
         ----------
-        attrs : dict
-            dict of attributes to add to the namespace.
-        attrs: Dict[str, Any]
+        attrs : Dict[str, Any]
+            Dict of attributes to add to the namespace.
 
         Raises
         ------
         AttributeError
-            existing attribute found.
+            Existing attribute found.
         """
         for attr, value in attrs.items():
             if hasattr(cls, attr):
@@ -65,23 +68,20 @@ class BaseNamespace(SimpleNamespace):
             setattr(cls, attr, value)
 
     @classmethod
-    def extend_functions(cls, *funcs: Callable):
+    def extend_functions(cls, *funcs: Callable) -> None:
         """Extends the namespace class by adding functions as attributes. The
         function will be added as a staticmethod.
 
         Parameters
         ----------
         *funcs : Callable
-            functions to be added to the namespace.
-
-        Returns
-        -------
+            Functions to be added to the namespace.
         """
         for func in funcs:
             cls.extend({func.__name__: staticmethod(func)})
 
 
-class TypeNamespaceMixin:  # pylint:disable=too-few-public-methods
+class TypeNamespaceMixin:
     """
     Mixin to handle namespaced types.
     """
@@ -129,27 +129,30 @@ class TypeNamespaceMixin:  # pylint:disable=too-few-public-methods
 @dynamic_class("namespaces")
 def _create_namespace_cls(
     prefix: str,
-    docstring: str = None,
+    docstring: Optional[str] = None,
     base: SimpleNamespace = BaseNamespace,
-    mixins: List[type] = None,
+    mixins: Optional[List[type]] = None,
+    module: BoulderModule = BoulderModule.QCTRL,
 ) -> SimpleNamespace:
     """Creates a new namespace class and returns an instance of it.
 
     Parameters
     ----------
-    prefix: str
-        prefix for the all core namespace. (i.e core__ )
-    docstring: str
-         namespace docstring. (Default value = None)
-    base: SimpleNamespace
-         namespace base. (Default value = BaseNamespace)
-    mixins: List[type]
-         nested mixins (Default value = None)
+    prefix : str
+        A prefix for the all core namespace. (i.e core__ )
+    docstring : str, optional
+        Namespace docstring. Defaults to `None`.
+    base : SimpleNamespace, optional
+        Namespace base. Defaults to `BaseNamespace`.
+    mixins : List[type], optional
+        Nested mixins. Defaults to `None`.
+    module : BoulderModule, optional
+        The module to which the namespace belongs. Defaults to `BoulderModule.QCTRL`.
 
     Returns
     -------
     SimpleNamespace
-        formatted namespace.
+        Formatted namespace.
     """
     name = f"{inflection.camelize(prefix)}Namespace"
     parents = [base]
@@ -157,7 +160,7 @@ def _create_namespace_cls(
     if mixins:
         parents += mixins
 
-    attrs = {}
+    attrs = {"__module__": module.value}
 
     if docstring:
         attrs.update({"__doc__": docstring})
@@ -182,6 +185,7 @@ def create_type_namespace():
 
 __all__ = [
     "BaseNamespace",
+    "BoulderModule",
     "create_function_namespace",
     "create_type_namespace",
 ]
