@@ -46,7 +46,10 @@ from qctrl.builders.doc import (
     ClassAttribute,
     ClassDocstring,
 )
-from qctrl.dynamic import register_dynamic_class
+from qctrl.dynamic import (
+    BoulderModule,
+    register_dynamic_class,
+)
 from qctrl.utils import (
     _is_deprecated,
     _is_undefined,
@@ -464,4 +467,4 @@ class TypeRegistry(BaseTypeRegistry):
             raise KeyError(f"duplicate type name: {key}")
 
         self._types[key] = cls
-        register_dynamic_class(cls, submodule)
+        register_dynamic_class(cls, submodule, BoulderModule.QCTRL)
